pub(crate) struct UserFunctionAttr {
pub(crate) name: String,
pub(crate) async_: bool,
pub(crate) context: bool,
pub(crate) writer_type_kind: Option<WriterTypeKind>,
pub(crate) retract: bool,
pub(crate) args_option: Vec<bool>,
pub(crate) first_mut_ref_arg: Option<String>,
pub(crate) return_type_kind: ReturnTypeKind,
pub(crate) iterator_item_kind: Option<ReturnTypeKind>,
pub(crate) core_return_type: String,
pub(crate) generic: usize,
pub(crate) return_type_span: Span,
}Expand description
Attributes from function signature fn(..)
Fields
name: StringFunction name
async_: boolWhether the function is async.
context: boolWhether contains argument &Context.
writer_type_kind: Option<WriterTypeKind>The writer type kind, if any, such as impl std::fmt::Write.
retract: boolWhether the last argument type is retract: bool.
args_option: Vec<bool>Whether each argument type is Option<T>.
first_mut_ref_arg: Option<String>If the first argument type is &mut T, then Some(T).
return_type_kind: ReturnTypeKindThe return type kind.
iterator_item_kind: Option<ReturnTypeKind>The kind of inner type T in impl Iterator<Item = T>
core_return_type: StringThe core return type without Option or Result.
generic: usizeThe number of generic types.
return_type_span: SpanThe span of return type.
Implementations